@@ -188,6 +188,10 @@
 # include <drm/drm_framebuffer.h>
 #endif
 
+#if RTLNX_VER_MIN(6,19,0)
+#include <drm/drm_print.h>
+#endif
+
 #include "vboxvideo_guest.h"
 #include "vboxvideo_vbe.h"
 #include "hgsmi_ch_setup.h"
