@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2024 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2025 Oracle and/or its affiliates.
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
@@ -295,512 +295,6 @@ typedef struct VBOXVIDEOINFOQUERYCONF32 {
 } VBOXVIDEOINFOQUERYCONF32;
 #pragma pack()
 
-#ifdef VBOX_WITH_VIDEOHWACCEL
-#pragma pack(1)
-
-#define VBOXVHWA_VERSION_MAJ 0
-#define VBOXVHWA_VERSION_MIN 0
-#define VBOXVHWA_VERSION_BLD 6
-#define VBOXVHWA_VERSION_RSV 0
-
-typedef enum {
-	VBOXVHWACMD_TYPE_SURF_CANCREATE = 1,
-	VBOXVHWACMD_TYPE_SURF_CREATE,
-	VBOXVHWACMD_TYPE_SURF_DESTROY,
-	VBOXVHWACMD_TYPE_SURF_LOCK,
-	VBOXVHWACMD_TYPE_SURF_UNLOCK,
-	VBOXVHWACMD_TYPE_SURF_BLT,
-	VBOXVHWACMD_TYPE_SURF_FLIP,
-	VBOXVHWACMD_TYPE_SURF_OVERLAY_UPDATE,
-	VBOXVHWACMD_TYPE_SURF_OVERLAY_SETPOSITION,
-	VBOXVHWACMD_TYPE_SURF_COLORKEY_SET,
-	VBOXVHWACMD_TYPE_QUERY_INFO1,
-	VBOXVHWACMD_TYPE_QUERY_INFO2,
-	VBOXVHWACMD_TYPE_ENABLE,
-	VBOXVHWACMD_TYPE_DISABLE,
-	VBOXVHWACMD_TYPE_HH_CONSTRUCT,
-	VBOXVHWACMD_TYPE_HH_RESET
-#ifdef VBOX_WITH_WDDM
-	, VBOXVHWACMD_TYPE_SURF_GETINFO
-	, VBOXVHWACMD_TYPE_SURF_COLORFILL
-#endif
-	, VBOXVHWACMD_TYPE_HH_DISABLE
-	, VBOXVHWACMD_TYPE_HH_ENABLE
-	, VBOXVHWACMD_TYPE_HH_SAVESTATE_SAVEBEGIN
-	, VBOXVHWACMD_TYPE_HH_SAVESTATE_SAVEEND
-	, VBOXVHWACMD_TYPE_HH_SAVESTATE_SAVEPERFORM
-	, VBOXVHWACMD_TYPE_HH_SAVESTATE_LOADPERFORM
-} VBOXVHWACMD_TYPE;
-
-/** The command processing was asynch, set by the host to indicate asynch
- * command completion. Must not be cleared once set, the command completion is
- * performed by issuing a host->guest completion command while keeping this
- * flag unchanged */
-#define VBOXVHWACMD_FLAG_HG_ASYNCH               0x00010000u
-/** asynch completion is performed by issuing the event */
-#define VBOXVHWACMD_FLAG_GH_ASYNCH_EVENT         0x00000001u
-/** issue interrupt on asynch completion */
-#define VBOXVHWACMD_FLAG_GH_ASYNCH_IRQ           0x00000002u
-/** Guest does not do any op on completion of this command, the host may copy
- * the command and indicate that it does not need the command anymore
- * by setting the VBOXVHWACMD_FLAG_HG_ASYNCH_RETURNED flag */
-#define VBOXVHWACMD_FLAG_GH_ASYNCH_NOCOMPLETION  0x00000004u
-/** the host has copied the VBOXVHWACMD_FLAG_GH_ASYNCH_NOCOMPLETION command and returned it to the guest */
-#define VBOXVHWACMD_FLAG_HG_ASYNCH_RETURNED      0x00020000u
-/** this is the host->host cmd, i.e. a configuration command posted by the host to the framebuffer */
-#define VBOXVHWACMD_FLAG_HH_CMD                  0x10000000u
-
-typedef struct VBOXVHWACMD {
-	VBOXVHWACMD_TYPE enmCmd;     /**< command type */
-	volatile s32 rc;         /**< command result */
-	s32 iDisplay;            /**< display index */
-	volatile s32 Flags;      /**< ORed VBOXVHWACMD_FLAG_xxx values */
-	uint64_t GuestVBVAReserved1; /**< field internally used by the guest VBVA cmd handling, must NOT be modified by clients */
-	uint64_t GuestVBVAReserved2; /**< field internally used by the guest VBVA cmd handling, must NOT be modified by clients */
-	volatile u32 cRefs;
-	s32 Reserved;
-	union {
-		struct VBOXVHWACMD *pNext;
-		u32            offNext;
-		uint64_t Data;                  /**< the body is 64-bit aligned */
-	} u;
-	char body[1];
-} VBOXVHWACMD;
-
-#define VBOXVHWACMD_HEADSIZE()                          (RT_OFFSETOF(VBOXVHWACMD, body))
-#define VBOXVHWACMD_SIZE_FROMBODYSIZE(a_cbBody)         (VBOXVHWACMD_HEADSIZE() + (a_cbBody))
-#define VBOXVHWACMD_SIZE(a_tTypeCmd)                    (VBOXVHWACMD_SIZE_FROMBODYSIZE(sizeof(a_tTypeCmd)))
-typedef unsigned int VBOXVHWACMD_LENGTH;
-typedef uint64_t VBOXVHWA_SURFHANDLE;
-#define VBOXVHWA_SURFHANDLE_INVALID                     UINT64_C(0)
-#define VBOXVHWACMD_BODY(a_pHdr, a_TypeBody)            ( (a_TypeBody  *)&(a_pHdr)->body[0] )
-#if !defined(IN_GUEST) && defined(IN_RING3)
-# define VBOXVHWACMD_BODY_HOST_HEAP(a_pHdr, a_TypeBody) ( (a_TypeBody *)&(a_pHdr)->body[0] )
-#endif
-#define VBOXVHWACMD_HEAD(a_pBody)\
-	( (VBOXVHWACMD  *)((u8 *)(a_pBody) - RT_OFFSETOF(VBOXVHWACMD, body)))
-
-typedef struct VBOXVHWA_RECTL {
-	s32 left;
-	s32 top;
-	s32 right;
-	s32 bottom;
-} VBOXVHWA_RECTL;
-
-typedef struct VBOXVHWA_COLORKEY {
-	u32 low;
-	u32 high;
-} VBOXVHWA_COLORKEY;
-
-typedef struct VBOXVHWA_PIXELFORMAT {
-	u32 flags;
-	u32 fourCC;
-	union {
-		u32 rgbBitCount;
-		u32 yuvBitCount;
-	} c;
-
-	union {
-		u32 rgbRBitMask;
-		u32 yuvYBitMask;
-	} m1;
-
-	union {
-		u32 rgbGBitMask;
-		u32 yuvUBitMask;
-	} m2;
-
-	union {
-		u32 rgbBBitMask;
-		u32 yuvVBitMask;
-	} m3;
-
-	union {
-		u32 rgbABitMask;
-	} m4;
-
-	u32 Reserved;
-} VBOXVHWA_PIXELFORMAT;
-
-typedef struct VBOXVHWA_SURFACEDESC {
-	u32 flags;
-	u32 height;
-	u32 width;
-	u32 pitch;
-	u32 sizeX;
-	u32 sizeY;
-	u32 cBackBuffers;
-	u32 Reserved;
-	VBOXVHWA_COLORKEY DstOverlayCK;
-	VBOXVHWA_COLORKEY DstBltCK;
-	VBOXVHWA_COLORKEY SrcOverlayCK;
-	VBOXVHWA_COLORKEY SrcBltCK;
-	VBOXVHWA_PIXELFORMAT PixelFormat;
-	u32 surfCaps;
-	u32 Reserved2;
-	VBOXVHWA_SURFHANDLE hSurf;
-	uint64_t offSurface;
-} VBOXVHWA_SURFACEDESC;
-
-typedef struct VBOXVHWA_BLTFX {
-	u32 flags;
-	u32 rop;
-	u32 rotationOp;
-	u32 rotation;
-	u32 fillColor;
-	u32 Reserved;
-	VBOXVHWA_COLORKEY DstCK;
-	VBOXVHWA_COLORKEY SrcCK;
-} VBOXVHWA_BLTFX;
-
-typedef struct VBOXVHWA_OVERLAYFX {
-	u32 flags;
-	u32 Reserved1;
-	u32 fxFlags;
-	u32 Reserved2;
-	VBOXVHWA_COLORKEY DstCK;
-	VBOXVHWA_COLORKEY SrcCK;
-} VBOXVHWA_OVERLAYFX;
-
-#define VBOXVHWA_CAPS_BLT               0x00000040
-#define VBOXVHWA_CAPS_BLTCOLORFILL      0x04000000
-#define VBOXVHWA_CAPS_BLTFOURCC         0x00000100
-#define VBOXVHWA_CAPS_BLTSTRETCH        0x00000200
-#define VBOXVHWA_CAPS_BLTQUEUE          0x00000080
-
-#define VBOXVHWA_CAPS_OVERLAY           0x00000800
-#define VBOXVHWA_CAPS_OVERLAYFOURCC     0x00002000
-#define VBOXVHWA_CAPS_OVERLAYSTRETCH    0x00004000
-#define VBOXVHWA_CAPS_OVERLAYCANTCLIP   0x00001000
-
-#define VBOXVHWA_CAPS_COLORKEY          0x00400000
-#define VBOXVHWA_CAPS_COLORKEYHWASSIST  0x01000000
-
-#define VBOXVHWA_SCAPS_BACKBUFFER       0x00000004
-#define VBOXVHWA_SCAPS_COMPLEX          0x00000008
-#define VBOXVHWA_SCAPS_FLIP             0x00000010
-#define VBOXVHWA_SCAPS_FRONTBUFFER      0x00000020
-#define VBOXVHWA_SCAPS_OFFSCREENPLAIN   0x00000040
-#define VBOXVHWA_SCAPS_OVERLAY          0x00000080
-#define VBOXVHWA_SCAPS_PRIMARYSURFACE   0x00000200
-#define VBOXVHWA_SCAPS_SYSTEMMEMORY     0x00000800
-#define VBOXVHWA_SCAPS_VIDEOMEMORY      0x00004000
-#define VBOXVHWA_SCAPS_VISIBLE          0x00008000
-#define VBOXVHWA_SCAPS_LOCALVIDMEM      0x10000000
-
-#define VBOXVHWA_PF_PALETTEINDEXED8     0x00000020
-#define VBOXVHWA_PF_RGB                 0x00000040
-#define VBOXVHWA_PF_RGBTOYUV            0x00000100
-#define VBOXVHWA_PF_YUV                 0x00000200
-#define VBOXVHWA_PF_FOURCC              0x00000004
-
-#define VBOXVHWA_LOCK_DISCARDCONTENTS   0x00002000
-
-#define VBOXVHWA_CFG_ENABLED            0x00000001
-
-#define VBOXVHWA_SD_BACKBUFFERCOUNT     0x00000020
-#define VBOXVHWA_SD_CAPS                0x00000001
-#define VBOXVHWA_SD_CKDESTBLT           0x00004000
-#define VBOXVHWA_SD_CKDESTOVERLAY       0x00002000
-#define VBOXVHWA_SD_CKSRCBLT            0x00010000
-#define VBOXVHWA_SD_CKSRCOVERLAY        0x00008000
-#define VBOXVHWA_SD_HEIGHT              0x00000002
-#define VBOXVHWA_SD_PITCH               0x00000008
-#define VBOXVHWA_SD_PIXELFORMAT         0x00001000
-/*#define VBOXVHWA_SD_REFRESHRATE       0x00040000*/
-#define VBOXVHWA_SD_WIDTH               0x00000004
-
-#define VBOXVHWA_CKEYCAPS_DESTBLT                  0x00000001
-#define VBOXVHWA_CKEYCAPS_DESTBLTCLRSPACE          0x00000002
-#define VBOXVHWA_CKEYCAPS_DESTBLTCLRSPACEYUV       0x00000004
-#define VBOXVHWA_CKEYCAPS_DESTBLTYUV               0x00000008
-#define VBOXVHWA_CKEYCAPS_DESTOVERLAY              0x00000010
-#define VBOXVHWA_CKEYCAPS_DESTOVERLAYCLRSPACE      0x00000020
-#define VBOXVHWA_CKEYCAPS_DESTOVERLAYCLRSPACEYUV   0x00000040
-#define VBOXVHWA_CKEYCAPS_DESTOVERLAYONEACTIVE     0x00000080
-#define VBOXVHWA_CKEYCAPS_DESTOVERLAYYUV           0x00000100
-#define VBOXVHWA_CKEYCAPS_SRCBLT                   0x00000200
-#define VBOXVHWA_CKEYCAPS_SRCBLTCLRSPACE           0x00000400
-#define VBOXVHWA_CKEYCAPS_SRCBLTCLRSPACEYUV        0x00000800
-#define VBOXVHWA_CKEYCAPS_SRCBLTYUV                0x00001000
-#define VBOXVHWA_CKEYCAPS_SRCOVERLAY               0x00002000
-#define VBOXVHWA_CKEYCAPS_SRCOVERLAYCLRSPACE       0x00004000
-#define VBOXVHWA_CKEYCAPS_SRCOVERLAYCLRSPACEYUV    0x00008000
-#define VBOXVHWA_CKEYCAPS_SRCOVERLAYONEACTIVE      0x00010000
-#define VBOXVHWA_CKEYCAPS_SRCOVERLAYYUV            0x00020000
-#define VBOXVHWA_CKEYCAPS_NOCOSTOVERLAY            0x00040000
-
-#define VBOXVHWA_BLT_COLORFILL                      0x00000400
-#define VBOXVHWA_BLT_DDFX                           0x00000800
-#define VBOXVHWA_BLT_EXTENDED_FLAGS                 0x40000000
-#define VBOXVHWA_BLT_EXTENDED_LINEAR_CONTENT        0x00000004
-#define VBOXVHWA_BLT_EXTENDED_PRESENTATION_STRETCHFACTOR 0x00000010
-#define VBOXVHWA_BLT_KEYDESTOVERRIDE                0x00004000
-#define VBOXVHWA_BLT_KEYSRCOVERRIDE                 0x00010000
-#define VBOXVHWA_BLT_LAST_PRESENTATION              0x20000000
-#define VBOXVHWA_BLT_PRESENTATION                   0x10000000
-#define VBOXVHWA_BLT_ROP                            0x00020000
-
-
-#define VBOXVHWA_OVER_DDFX                          0x00080000
-#define VBOXVHWA_OVER_HIDE                          0x00000200
-#define VBOXVHWA_OVER_KEYDEST                       0x00000400
-#define VBOXVHWA_OVER_KEYDESTOVERRIDE               0x00000800
-#define VBOXVHWA_OVER_KEYSRC                        0x00001000
-#define VBOXVHWA_OVER_KEYSRCOVERRIDE                0x00002000
-#define VBOXVHWA_OVER_SHOW                          0x00004000
-
-#define VBOXVHWA_CKEY_COLORSPACE                    0x00000001
-#define VBOXVHWA_CKEY_DESTBLT                       0x00000002
-#define VBOXVHWA_CKEY_DESTOVERLAY                   0x00000004
-#define VBOXVHWA_CKEY_SRCBLT                        0x00000008
-#define VBOXVHWA_CKEY_SRCOVERLAY                    0x00000010
-
-#define VBOXVHWA_BLT_ARITHSTRETCHY                  0x00000001
-#define VBOXVHWA_BLT_MIRRORLEFTRIGHT                0x00000002
-#define VBOXVHWA_BLT_MIRRORUPDOWN                   0x00000004
-
-#define VBOXVHWA_OVERFX_ARITHSTRETCHY               0x00000001
-#define VBOXVHWA_OVERFX_MIRRORLEFTRIGHT             0x00000002
-#define VBOXVHWA_OVERFX_MIRRORUPDOWN                0x00000004
-
-#define VBOXVHWA_CAPS2_CANRENDERWINDOWED            0x00080000
-#define VBOXVHWA_CAPS2_WIDESURFACES                 0x00001000
-#define VBOXVHWA_CAPS2_COPYFOURCC                   0x00008000
-/*#define VBOXVHWA_CAPS2_FLIPINTERVAL                 0x00200000*/
-/*#define VBOXVHWA_CAPS2_FLIPNOVSYNC                  0x00400000*/
-
-
-#define VBOXVHWA_OFFSET64_VOID        (UINT64_MAX)
-
-typedef struct VBOXVHWA_VERSION {
-	u32 maj;
-	u32 min;
-	u32 bld;
-	u32 reserved;
-} VBOXVHWA_VERSION;
-
-#define VBOXVHWA_VERSION_INIT(_pv) do { \
-		(_pv)->maj = VBOXVHWA_VERSION_MAJ; \
-		(_pv)->min = VBOXVHWA_VERSION_MIN; \
-		(_pv)->bld = VBOXVHWA_VERSION_BLD; \
-		(_pv)->reserved = VBOXVHWA_VERSION_RSV; \
-		} while(0)
-
-typedef struct VBOXVHWACMD_QUERYINFO1 {
-	union {
-		struct {
-			VBOXVHWA_VERSION guestVersion;
-		} in;
-
-		struct {
-			u32 cfgFlags;
-			u32 caps;
-
-			u32 caps2;
-			u32 colorKeyCaps;
-
-			u32 stretchCaps;
-			u32 surfaceCaps;
-
-			u32 numOverlays;
-			u32 curOverlays;
-
-			u32 numFourCC;
-			u32 reserved;
-		} out;
-	} u;
-} VBOXVHWACMD_QUERYINFO1;
-
-typedef struct VBOXVHWACMD_QUERYINFO2 {
-	u32 numFourCC;
-	u32 FourCC[1];
-} VBOXVHWACMD_QUERYINFO2;
-
-#define VBOXVHWAINFO2_SIZE(_cFourCC) RT_UOFFSETOF_DYN(VBOXVHWACMD_QUERYINFO2, FourCC[_cFourCC])
-
-typedef struct VBOXVHWACMD_SURF_CANCREATE {
-	VBOXVHWA_SURFACEDESC SurfInfo;
-	union {
-		struct {
-			u32 bIsDifferentPixelFormat;
-			u32 Reserved;
-		} in;
-
-		struct {
-			s32 ErrInfo;
-		} out;
-	} u;
-} VBOXVHWACMD_SURF_CANCREATE;
-
-typedef struct VBOXVHWACMD_SURF_CREATE {
-	VBOXVHWA_SURFACEDESC SurfInfo;
-} VBOXVHWACMD_SURF_CREATE;
-
-#ifdef VBOX_WITH_WDDM
-typedef struct VBOXVHWACMD_SURF_GETINFO {
-	VBOXVHWA_SURFACEDESC SurfInfo;
-} VBOXVHWACMD_SURF_GETINFO;
-#endif
-
-typedef struct VBOXVHWACMD_SURF_DESTROY {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hSurf;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_DESTROY;
-
-typedef struct VBOXVHWACMD_SURF_LOCK {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hSurf;
-			uint64_t offSurface;
-			u32 flags;
-			u32 rectValid;
-			VBOXVHWA_RECTL rect;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_LOCK;
-
-typedef struct VBOXVHWACMD_SURF_UNLOCK {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hSurf;
-			u32 xUpdatedMemValid;
-			u32 reserved;
-			VBOXVHWA_RECTL xUpdatedMemRect;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_UNLOCK;
-
-typedef struct VBOXVHWACMD_SURF_BLT {
-	uint64_t DstGuestSurfInfo;
-	uint64_t SrcGuestSurfInfo;
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hDstSurf;
-			uint64_t offDstSurface;
-			VBOXVHWA_RECTL dstRect;
-			VBOXVHWA_SURFHANDLE hSrcSurf;
-			uint64_t offSrcSurface;
-			VBOXVHWA_RECTL srcRect;
-			u32 flags;
-			u32 xUpdatedSrcMemValid;
-			VBOXVHWA_BLTFX desc;
-			VBOXVHWA_RECTL xUpdatedSrcMemRect;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_BLT;
-
-#ifdef VBOX_WITH_WDDM
-typedef struct VBOXVHWACMD_SURF_COLORFILL {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hSurf;
-			uint64_t offSurface;
-			u32 reserved;
-			u32 cRects;
-			VBOXVHWA_RECTL aRects[1];
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_COLORFILL;
-#endif
-
-typedef struct VBOXVHWACMD_SURF_FLIP {
-	uint64_t TargGuestSurfInfo;
-	uint64_t CurrGuestSurfInfo;
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hTargSurf;
-			uint64_t offTargSurface;
-			VBOXVHWA_SURFHANDLE hCurrSurf;
-			uint64_t offCurrSurface;
-			u32 flags;
-			u32 xUpdatedTargMemValid;
-			VBOXVHWA_RECTL xUpdatedTargMemRect;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_FLIP;
-
-typedef struct VBOXVHWACMD_SURF_COLORKEY_SET {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hSurf;
-			uint64_t offSurface;
-			VBOXVHWA_COLORKEY CKey;
-			u32 flags;
-			u32 reserved;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_COLORKEY_SET;
-
-#define VBOXVHWACMD_SURF_OVERLAY_UPDATE_F_SRCMEMRECT 0x00000001
-#define VBOXVHWACMD_SURF_OVERLAY_UPDATE_F_DSTMEMRECT 0x00000002
-
-typedef struct VBOXVHWACMD_SURF_OVERLAY_UPDATE {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hDstSurf;
-			uint64_t offDstSurface;
-			VBOXVHWA_RECTL dstRect;
-			VBOXVHWA_SURFHANDLE hSrcSurf;
-			uint64_t offSrcSurface;
-			VBOXVHWA_RECTL srcRect;
-			u32 flags;
-			u32 xFlags;
-			VBOXVHWA_OVERLAYFX desc;
-			VBOXVHWA_RECTL xUpdatedSrcMemRect;
-			VBOXVHWA_RECTL xUpdatedDstMemRect;
-		} in;
-	} u;
-}VBOXVHWACMD_SURF_OVERLAY_UPDATE;
-
-typedef struct VBOXVHWACMD_SURF_OVERLAY_SETPOSITION {
-	union {
-		struct {
-			VBOXVHWA_SURFHANDLE hDstSurf;
-			uint64_t offDstSurface;
-			VBOXVHWA_SURFHANDLE hSrcSurf;
-			uint64_t offSrcSurface;
-			u32 xPos;
-			u32 yPos;
-			u32 flags;
-			u32 reserved;
-		} in;
-	} u;
-} VBOXVHWACMD_SURF_OVERLAY_SETPOSITION;
-
-typedef struct VBOXVHWACMD_HH_CONSTRUCT {
-	void    *pVM;
-	/* VRAM info for the backend to be able to properly translate VRAM offsets */
-	void    *pvVRAM;
-	u32 cbVRAM;
-} VBOXVHWACMD_HH_CONSTRUCT;
-
-typedef struct VBOXVHWACMD_HH_SAVESTATE_SAVEPERFORM {
-	struct SSMHANDLE * pSSM;
-} VBOXVHWACMD_HH_SAVESTATE_SAVEPERFORM;
-
-typedef struct VBOXVHWACMD_HH_SAVESTATE_LOADPERFORM {
-	struct SSMHANDLE * pSSM;
-} VBOXVHWACMD_HH_SAVESTATE_LOADPERFORM;
-
-typedef void FNVBOXVHWA_HH_CALLBACK(void *);
-typedef FNVBOXVHWA_HH_CALLBACK *PFNVBOXVHWA_HH_CALLBACK;
-
-#define VBOXVHWA_HH_CALLBACK_SET(_pCmd, _pfn, _parg) \
-	do { \
-		(_pCmd)->GuestVBVAReserved1 = (uint64_t)(uintptr_t)(_pfn); \
-		(_pCmd)->GuestVBVAReserved2 = (uint64_t)(uintptr_t)(_parg); \
-	}while(0)
-
-#define VBOXVHWA_HH_CALLBACK_GET(_pCmd) ((PFNVBOXVHWA_HH_CALLBACK)(_pCmd)->GuestVBVAReserved1)
-#define VBOXVHWA_HH_CALLBACK_GET_ARG(_pCmd) ((void*)(_pCmd)->GuestVBVAReserved2)
-
-#pragma pack()
-#endif /* #ifdef VBOX_WITH_VIDEOHWACCEL */
-
 /* All structures are without alignment. */
 #pragma pack(1)
 
@@ -842,9 +336,6 @@ typedef struct VBVABUFFER {
  * causes a complete screen update. */
 #define VBVA_ENABLE       7
 #define VBVA_MOUSE_POINTER_SHAPE 8
-#ifdef VBOX_WITH_VIDEOHWACCEL
-# define VBVA_VHWA_CMD    9
-#endif /* # ifdef VBOX_WITH_VIDEOHWACCEL */
 #ifdef VBOX_WITH_VDMA
 # define VBVA_VDMA_CTL   10 /* setup G<->H DMA channel info */
 # define VBVA_VDMA_CMD    11 /* G->H DMA command             */
@@ -869,15 +360,6 @@ typedef struct VBVABUFFER {
 #define VBVAHG_SHGSMI_COMPLETION  3
 #endif
 
-#ifdef VBOX_WITH_VIDEOHWACCEL
-#define VBVAHG_DCUSTOM_VHWA_CMDCOMPLETE 1
-#pragma pack(1)
-typedef struct VBVAHOSTCMDVHWACMDCOMPLETE {
-	u32 offCmd;
-}VBVAHOSTCMDVHWACMDCOMPLETE;
-#pragma pack()
-#endif /* # ifdef VBOX_WITH_VIDEOHWACCEL */
-
 #pragma pack(1)
 typedef enum {
 	VBVAHOSTCMD_OP_EVENT = 1,
